@@ -2,19 +2,18 @@
  FILE: icalvalue.c
  CREATOR: eric 02 May 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
-     http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at http://www.mozilla.org/MPL/
+    the License at https://www.mozilla.org/MPL/
 
   Contributions from:
      Graham Davison <g.m.davison@computer.org>
@@ -304,10 +303,11 @@ static char *icalmemory_strdup_and_quote(const icalvalue *value, const char *unq
         case ',':
             /* unescaped COMMA is allowed in CATEGORIES property as its
                considered a list delimiter here, see:
-               http://tools.ietf.org/html/rfc5545#section-3.8.1.2 */
+               https://tools.ietf.org/html/rfc5545#section-3.8.1.2 */
             if ((icalproperty_isa(value->parent) == ICAL_CATEGORIES_PROPERTY) ||
                 (icalproperty_isa(value->parent) == ICAL_RESOURCES_PROPERTY) ||
-                (icalproperty_isa(value->parent) == ICAL_POLLPROPERTIES_PROPERTY)) {
+                (icalproperty_isa(value->parent) == ICAL_POLLPROPERTIES_PROPERTY) ||
+                (icalproperty_isa(value->parent) == ICAL_X_PROPERTY)) {
                 icalmemory_append_char(&str, &str_p, &buf_sz, *p);
                 break;
             }
@@ -365,8 +365,8 @@ static icalvalue *icalvalue_new_enum(icalvalue_kind kind, int x_type, const char
  * The decimal separator (if any) of the double has to be '.'
  * The code is locale *independent* and does *not* change the locale.
  * It should be thread safe.
- * If you want a code that that does the same job with a decimal separator
- * dependant on the current locale, then use strtof() from libc.
+ * If you want a code that does the same job with a decimal separator
+ * dependent on the current locale, then use strtof() from libc.
  */
 static int simple_str_to_double(const char *from, double *result, char **to)
 {
@@ -385,17 +385,16 @@ static int simple_str_to_double(const char *from, double *result, char **to)
     }
 
     /*skip the white spaces at the beginning */
-    while (cur && isspace((int)*cur))
+    while (*cur && isspace((int)*cur))
         cur++;
 
     start = cur;
-    /*
-     * copy the part that looks like a double into tmp_buf
+    /* copy the part that looks like a double into tmp_buf
      * so that we can call strtof() on it.
      * during the copy, we give ourselves a chance to convert the '.'
      * into the decimal separator of the current locale.
      */
-    while (cur && (isdigit((int)*cur) || *cur == '.' || *cur == '+' || *cur == '-')) {
+    while (*cur && (isdigit((int)*cur) || *cur == '.' || *cur == '+' || *cur == '-')) {
         ++cur;
     }
     end = cur;
@@ -405,8 +404,7 @@ static int simple_str_to_double(const char *from, double *result, char **to)
     }
     memset(tmp_buf, 0, TMP_NUM_SIZE + 1);
 
-    /*
-     * copy the float number string into tmp_buf, and take
+    /* copy the float number string into tmp_buf, and take
      * care to have the (optional) decimal separator be the one
      * of the current locale.
      */
@@ -430,6 +428,12 @@ static int simple_str_to_double(const char *from, double *result, char **to)
     return 0;
 }
 
+static void free_icalvalue_attach_data(char *data, void *user_data)
+{
+    _unused(user_data);
+    free(data);
+}
+
 static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                                                        const char *str, icalproperty ** error)
 {
@@ -460,7 +464,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
         {
             icalattach *attach;
 
-            attach = icalattach_new_from_data(str, NULL, 0);
+            attach = icalattach_new_from_data(strdup(str), free_icalvalue_attach_data, 0);
             if (!attach)
               break;
 
@@ -482,7 +486,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                          "Could not parse %s as a %s property",
                          str, icalvalue_kind_to_string(kind));
                 errParam = icalparameter_new_xlicerrortype(ICAL_XLICERRORTYPE_VALUEPARSEERROR);
-                *error = icalproperty_vanew_xlicerror(temp, errParam, 0);
+                *error = icalproperty_vanew_xlicerror(temp, errParam, (void *)0);
                 icalparameter_free(errParam);
             }
             break;
@@ -539,7 +543,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
         {
             int t, utcoffset, hours, minutes, seconds;
 
-            /* treat the UTCOFSET string a a decimal number, disassemble its digits
+            /* treat the UTCOFSET string as a decimal number, disassemble its digits
                and reconstruct it as sections */
             t = strtol(str, 0, 10);
             /* add phantom seconds field */
@@ -618,7 +622,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                          "Could not parse %s as a %s property",
                          str, icalvalue_kind_to_string(kind));
                 errParam = icalparameter_new_xlicerrortype(ICAL_XLICERRORTYPE_VALUEPARSEERROR);
-                *error = icalproperty_vanew_xlicerror(temp, errParam, 0);
+                *error = icalproperty_vanew_xlicerror(temp, errParam, (void *)0);
                 icalparameter_free(errParam);
             }
         }
@@ -733,7 +737,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                 snprintf(temp, TMP_BUF_SIZE, "Unknown type for \'%s\'", str);
 
                 errParam = icalparameter_new_xlicerrortype(ICAL_XLICERRORTYPE_VALUEPARSEERROR);
-                *error = icalproperty_vanew_xlicerror(temp, errParam, 0);
+                *error = icalproperty_vanew_xlicerror(temp, errParam, (void *)0);
                 icalparameter_free(errParam);
             }
 
@@ -896,10 +900,13 @@ static char *icalvalue_utcoffset_as_ical_string_r(const icalvalue *value)
     m = (data - (h * 3600)) / 60;
     s = (data - (h * 3600) - (m * 60));
 
+    h = MIN(abs(h), 23);
+    m = MIN(abs(m), 59);
+    s = MIN(abs(s), 59);
     if (s != 0) {
-        snprintf(str, 9, "%c%02d%02d%02d", sign, abs(h), abs(m), abs(s));
+        snprintf(str, 9, "%c%02d%02d%02d", sign, h, m, s);
     } else {
-        snprintf(str, 9, "%c%02d%02d", sign, abs(h), abs(m));
+        snprintf(str, 9, "%c%02d%02d", sign, h, m);
     }
 
     return str;
@@ -1513,8 +1520,8 @@ int icalvalue_decode_ical_string(const char *szText, char *szDecText, int nMaxBu
     if ((szText == 0) || (szDecText == 0))
         return 0;
 
-    buf_sz = strlen(szText);
-    str_p = str = (char *)icalmemory_new_buffer(buf_sz + 1);
+    buf_sz = strlen(szText) + 1;
+    str_p = str = (char *)icalmemory_new_buffer(buf_sz);
 
     if (str_p == 0) {
         return 0;
@@ -1527,11 +1534,14 @@ int icalvalue_decode_ical_string(const char *szText, char *szDecText, int nMaxBu
         } else {
             icalmemory_append_char(&str, &str_p, &buf_sz, *p);
         }
+
+        if (str_p - str > nMaxBufferLen)
+            break;
     }
 
     icalmemory_append_char(&str, &str_p, &buf_sz, '\0');
 
-    if ((int)strlen(str) > nMaxBufferLen) {
+    if ((int)strlen(str) >= nMaxBufferLen) {
         icalmemory_free_buffer(str);
         return 0;
     }
