@@ -282,16 +282,16 @@ void create_new_component_with_va_args()
                                 (void *)0),
             (void *)0);
 
-    ok("creating a complex vcalendar", (calendar != NULL));
     if (VERBOSE && calendar)
         printf("%s\n", icalcomponent_as_ical_string(calendar));
 
     icalcomponent_free(calendar);
+    ok("creating a complex vcalendar", (calendar != NULL));
 }
 
 static void print_span(int c, struct icaltime_span span)
 {
-    printf("span-->%d, %d\n", (int)span.start, (int)span.end);
+    printf("span-->%ld, %ld\n", (long)span.start, (long)span.end);
     if (span.start == 0) {
         printf("#%02d start: (empty)\n", c);
     } else {
@@ -336,19 +336,19 @@ void test_icalcomponent_get_span()
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
             icalproperty_vanew_dtstart(icaltime_from_timet_with_zone(tm1, 0, azone),
-                                       icalparameter_new_tzid("America/Los_Angeles"), 0),
+                                       icalparameter_new_tzid("America/Los_Angeles"), (void *)0),
             icalproperty_vanew_dtend(icaltime_from_timet_with_zone(tm2, 0, azone),
                                      icalparameter_new_tzid("America/Los_Angeles"), 0),
             (void *)0);
 
     span = icalcomponent_get_span(c);
+    icalcomponent_free(c);
     if (VERBOSE)
         print_span(tnum++, span);
 
 #if ADD_TESTS_BROKEN_BUILTIN_TZDATA
     int_is("America/Los_Angeles", span.start, 973350000);
 #endif
-    icalcomponent_free(c);
 
     /** test 2
      *  We specify times as floating, the returned span is in UTC
@@ -356,15 +356,15 @@ void test_icalcomponent_get_span()
      */
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
-            icalproperty_vanew_dtstart(icaltime_from_timet_with_zone(tm1, 0, NULL), 0),
-            icalproperty_vanew_dtend(icaltime_from_timet_with_zone(tm2, 0, NULL), 0),
+            icalproperty_vanew_dtstart(icaltime_from_timet_with_zone(tm1, 0, NULL), (void *)0),
+            icalproperty_vanew_dtend(icaltime_from_timet_with_zone(tm2, 0, NULL), (void *)0),
             (void *)0);
 
     span = icalcomponent_get_span(c);
     if (VERBOSE)
         print_span(tnum++, span);
 
-    int_is("floating time", (int)span.start, (int)tm1);
+    int_is("floating time", (int)(long)span.start, (int)(long)tm1);
 
     icalcomponent_free(c);
 
@@ -375,19 +375,19 @@ void test_icalcomponent_get_span()
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
             icalproperty_vanew_dtstart(icaltime_from_timet_with_zone(tm1, 0, azone),
-                                       icalparameter_new_tzid("America/New_York"), 0),
+                                       icalparameter_new_tzid("America/New_York"), (void *)0),
             icalproperty_vanew_dtend(icaltime_from_timet_with_zone(tm2, 0, azone),
-                                     icalparameter_new_tzid("America/New_York"), 0),
+                                     icalparameter_new_tzid("America/New_York"), (void *)0),
             (void *)0);
 
     span = icalcomponent_get_span(c);
+    icalcomponent_free(c);
     if (VERBOSE)
         print_span(tnum++, span);
 
 #if ADD_TESTS_BROKEN_BUILTIN_TZDATA
     int_is("America/New_York", span.start, 973360800);
 #endif
-    icalcomponent_free(c);
 
     /** test 4
      *  We specify times in two different timezones, the returned span
@@ -398,19 +398,19 @@ void test_icalcomponent_get_span()
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
             icalproperty_vanew_dtstart(icaltime_from_timet_with_zone(tm1, 0, azone),
-                                       icalparameter_new_tzid("America/New_York"), 0),
+                                       icalparameter_new_tzid("America/New_York"), (void *)0),
             icalproperty_vanew_dtend(icaltime_from_timet_with_zone(tm2, 0, bzone),
-                                     icalparameter_new_tzid("America/Los_Angeles"), 0),
-            (void *)0);
+                                     icalparameter_new_tzid("America/Los_Angeles"), (void *)0),
+        (void *)0);
 
     span = icalcomponent_get_span(c);
+    icalcomponent_free(c);
     if (VERBOSE)
         print_span(tnum++, span);
 
 #if ADD_TESTS_BROKEN_BUILTIN_TZDATA
     int_is("America/New_York", span.start, 973360800);
 #endif
-    icalcomponent_free(c);
 
     /** test 5
      *  We specify start time in a timezone and a duration, the returned span
@@ -422,18 +422,18 @@ void test_icalcomponent_get_span()
     c = icalcomponent_vanew(
             ICAL_VEVENT_COMPONENT,
             icalproperty_vanew_dtstart(icaltime_from_timet_with_zone(tm1, 0, azone),
-                                       icalparameter_new_tzid("America/Los_Angeles"), 0),
+                                       icalparameter_new_tzid("America/Los_Angeles"), (void *)0),
             icalproperty_new_duration(dur),
             (void *)0);
 
     span = icalcomponent_get_span(c);
+    icalcomponent_free(c);
     if (VERBOSE)
         print_span(tnum++, span);
 
 #if ADD_TESTS_BROKEN_BUILTIN_TZDATA
     int_is("America/Los_Angeles w/ duration", span.end, 973351800);
 #endif
-    icalcomponent_free(c);
 
     icalerror_set_errors_are_fatal(0);
     /** test 6
@@ -448,7 +448,7 @@ void test_icalcomponent_get_span()
     if (VERBOSE)
         print_span(tnum++, span);
 
-    int_is("start == end", (int)span.start, (int)span.end);
+    int_is("start == end", (int)(long)span.start, (int)(long)span.end);
     icalcomponent_free(c);
 
     /** test 7
@@ -464,7 +464,7 @@ void test_icalcomponent_get_span()
     if (VERBOSE)
         print_span(tnum++, span);
 
-    int_is("UTC", (int)span.start, 973296000);
+    int_is("UTC", (int)(long)span.start, 973296000);
     icalcomponent_free(c);
 
     /** test 8
@@ -476,7 +476,7 @@ void test_icalcomponent_get_span()
                             (void *)0);
 
     span = icalcomponent_get_span(c);
-    int_is("UTC #2", (int)span.start, 973296000);
+    int_is("UTC #2", (int)(long)span.start, 973296000);
     if (VERBOSE)
         print_span(tnum++, span);
 
@@ -493,7 +493,7 @@ void test_icalcomponent_get_span()
     if (VERBOSE)
         print_span(tnum++, span);
 
-    int_is("start date only", (int)span.end, 973382399);
+    int_is("start date only", (int)(long)span.end, 973382399);
 
     icalcomponent_free(c);
 
